@@ -1,8 +1,11 @@
 /*
-   cfftb.c
-   Swarztrauber complex FFT routines (backward direction).
-
-   $Id$
+ * $Id: cfftb.c,v 1.1.1.1 2005/09/18 22:04:52 dhmunro Exp $
+ * Swarztrauber complex FFT routines (backward direction).
+ */
+/* Copyright (c) 2005, The Regents of the University of California.
+ * All rights reserved.
+ * This file is part of yorick (http://yorick.sourceforge.net).
+ * Read the accompanying LICENSE file for details.
  */
 
 #include "cfft.h"
