@@ -1,8 +1,11 @@
 /*
-   DGESV.C
-   LAPACK routines to solve a matrix by LU decomposition.
-
-   $Id$
+ * $Id: dgesv.c,v 1.1.1.1 2005/09/18 22:04:44 dhmunro Exp $
+ *  LAPACK routines to solve a matrix by LU decomposition.
+ */
+/* Copyright (c) 2005, The Regents of the University of California.
+ * All rights reserved.
+ * This file is part of yorick (http://yorick.sourceforge.net).
+ * Read the accompanying LICENSE file for details.
  */
 
 #include "dg.h"
